focal property
The focal point of this RadialSteps.
If specified, the RadialSteps will appear to be focused
along the vector from center to focal.
See center for a description of how the coordinates are mapped.
If this value is specified and focalRadius is greater than 0.0,
care should be taken to ensure that either this value or center
will not both resolve to Offset.zero, which would fail
to create a valid RadialSteps.
Copied from RadialGradient.
Implementation
final AlignmentGeometry? focal;