tileMode property
How this RadialSteps should tile the plane
beyond the outer ring at radius pixels from the center.
For details, see TileMode.


Copied from RadialGradient.
Implementation
final TileMode tileMode;
How this RadialSteps should tile the plane
beyond the outer ring at radius pixels from the center.
For details, see TileMode.


Copied from RadialGradient.
final TileMode tileMode;